package com.example.controller.admin;

import com.example.dto.PageQueryDTO;
import com.example.result.PageResult;
import com.example.result.Result;
import com.example.service.AdminService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.annotations.Results;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@Slf4j
@Api(tags = "管理员相关接口")
@RequestMapping("/admin")
public class AdminController {
    @Autowired
    private AdminService adminService;

    /**
     * 账号分页查询
     *
     * @param pageQueryDTO
     * @return
     */
    @GetMapping("/page")
    @ApiOperation(value = "账号分页查询")
    public Result<PageResult> page(PageQueryDTO pageQueryDTO) {
        log.info("账号分页查询，查询参数:{}", pageQueryDTO);
        PageResult pageResult = adminService.page(pageQueryDTO);
        return Result.success(pageResult);
    }

    //启用禁用老师账号
    @PostMapping("/status/{status}")
    @ApiOperation("启用禁用老师账号")
    public Result starOrStop(@PathVariable Integer status, Long id) {
        log.info("启用禁用老师账号:{},{}", id, status);
        adminService.starOrStop(id, status);
        return Result.success();
    }

    //删除老师账号
    @DeleteMapping("/{id}")
    @ApiOperation(value = "删除老师账号")
    public Result deleteById(@PathVariable Long id) {
        log.info("删除老师账号:{}", id);
        adminService.deleteById(id);
        return Result.success();
    }
}
