package com.example.service.impl;

import com.example.constant.MessageConstant;
import com.example.context.BaseContext;
import com.example.dto.PatentDTO;
import com.example.entity.Patent;
import com.example.exception.AwordsNotFoundException;
import com.example.mapper.PatentMapper;
import com.example.mapper.TeacherMapper;
import com.example.service.PatentService;
import com.example.service.PatentService;
import com.example.vo.PatentVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class PatentServiceImpl implements PatentService {

    @Autowired
    private PatentMapper patentMapper;
    @Autowired
    private TeacherMapper teacherMapper;

    /**
     * 老师专利上传
     *
     * @param patentDTO
     */
    @Override
    public void uploadPatent(PatentDTO patentDTO) {
        Patent patent = new Patent();
        BeanUtils.copyProperties(patentDTO, patent);
        Long id = BaseContext.getCurrentId();
        patent.setTeacherId(id);
        patentMapper.uploadPatent(patent);
    }

    /**
     * 老师专利修改
     *
     * @param patentDTO
     * @param id
     */
    @Override
    public void updatePatent(PatentDTO patentDTO, Long id) {
        Patent patent = new Patent();
        BeanUtils.copyProperties(patentDTO, patent);
        patent.setId(id);
        patentMapper.updatePatent(patent);
    }

    /**
     * 获取指定专利详细信息
     *
     * @param id
     * @return
     */
    @Override
    public PatentVO getById(Long id) {

        PatentVO patentVO = new PatentVO();
        Patent patent = patentMapper.getById(id);
        if(patent == null){
            throw new AwordsNotFoundException(MessageConstant.Patent_NOT_FOUND);
        }
        BeanUtils.copyProperties(patent,patentVO);
        return patentVO;
    }

    /**
     * 删除指定专利
     *
     * @param id
     */
    @Override
    public void deleteById(Long id) {
        patentMapper.deleteById(id);
    }

}
