package com.example.service.impl;

import com.example.context.BaseContext;
import com.example.dto.PageQueryDTO;
import com.example.dto.ResourceDTO;
import com.example.entity.Resource;
import com.example.mapper.ResourceMapper;
import com.example.result.PageResult;
import com.example.service.ResourceService;
import com.example.vo.ResourceVO;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;

@Service
public class ResourceServiceImpl implements ResourceService {

    @Autowired
    private ResourceMapper resourceMapper;

    /**
     * 资料库上传
     * @param resourceDTO
     */
    @Override
    public void upload(ResourceDTO resourceDTO) {
        Resource resource = new Resource();
        BeanUtils.copyProperties(resourceDTO,resource);
        resource.setUploader(BaseContext.getCurrentId());
        resource.setCreateTime(LocalDateTime.now());
        resourceMapper.upload(resource);
    }

    /**
     * 指定资料修改
     * @param resourceDTO
     * @param id
     */
    @Override
    public void update(ResourceDTO resourceDTO,Long id) {
        Resource resource = new Resource();
        BeanUtils.copyProperties(resourceDTO,resource);
        resource.setId(id);
        resourceMapper.update(resource);
    }

    /**
     * 指定资料删除
     * @param id
     */
    @Override
    public void delete(Long id) {
        resourceMapper.delete(id);
    }

    /**
     * 查询指定资料
     * @param id
     * @return
     */
    @Override
    public ResourceVO getById(Long id) {
        Resource resource = resourceMapper.getById(id);
        ResourceVO resourceVO=new ResourceVO();
        BeanUtils.copyProperties(resource,resourceVO);
        return resourceVO;
    }

    /**
     *
     * 资料分页查询
     * @param pageQueryDTO
     * @return
     */
    @Override
    public PageResult getAll(PageQueryDTO pageQueryDTO) {
        PageHelper.startPage(pageQueryDTO.getPage(),pageQueryDTO.getPageSize());
        Page<Resource> page=resourceMapper.getAll(pageQueryDTO);
        Long total=page.getTotal();
        List<Resource> result=page.getResult();
        return new PageResult(total,result);
    }
}
