package com.example.service.impl;

import com.example.constant.MessageConstant;
import com.example.context.BaseContext;
import com.example.dto.AwardsDTO;
import com.example.dto.WorkDTO;
import com.example.entity.Awards;
import com.example.entity.Work;
import com.example.exception.WorkNotFoundException;
import com.example.mapper.WorkMapper;
import com.example.service.WorkService;
import com.example.vo.WorkVO;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class WorkServiceImpl implements WorkService {

    @Autowired
    private WorkMapper workMapper;

    /**
     * 老师著作上传
     *
     * @param workDTO
     */
    @Override
    public void uploadWork(WorkDTO workDTO) {
        Work work = new Work();
        BeanUtils.copyProperties(workDTO, work);
        Long id = BaseContext.getCurrentId();
        work.setTeacherId(id);
        workMapper.uploadWork(work);
        workMapper.addWorkNum(id);
    }

    /**
     * 老师著作修改
     *
     * @param workDTO
     * @param id
     */
    @Override
    public void updateWork(WorkDTO workDTO, Long id) {
        Work work = new Work();
        BeanUtils.copyProperties(workDTO, work);
        work.setId(id);
        workMapper.updateWork(work);
    }

    /**
     * 指定著作查询
     *
     * @param id
     * @return
     */
    @Override
    public WorkVO getById(Long id) {
        WorkVO workVO = new WorkVO();
        Work work = workMapper.getById(id);
        if(work == null){
            throw new WorkNotFoundException(MessageConstant.WORK_NOT_FOUND);
        }
        BeanUtils.copyProperties(work,workVO);
        return workVO;
    }

    /**
     * 指定著作删除
     *
     * @param id
     */
    @Override
    public void deleteById(Long id) {
        workMapper.deleteById(id);
    }
}
